| Title: | Lexicons for Portuguese Text Analysis |
|---|---|
| Description: | Provides easy access for sentiment lexicons for those who want to do text analysis in Portuguese texts. As of now, two Portuguese lexicons are available: 'SentiLex-PT02' and 'OpLexicon' (v2.1 and v3.0). |
| Authors: | Sillas Gonzaga [aut, cre] |
| Maintainer: | Sillas Gonzaga <[email protected]> |
| License: | GPL-2 | file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-15 06:02:40 UTC |
| Source: | https://github.com/sillasgonzaga/lexiconpt |
Lookup word or term in datasets available on lexiconPT
get_word_sentiment(word, dictionary = c("all", "oplexicon_v2", "oplexicon_v3", "sentilex"))get_word_sentiment(word, dictionary = c("all", "oplexicon_v2", "oplexicon_v3", "sentilex"))
word |
character. |
A list of all datasets available on lexiconPT filtered by the inputed word.
{ get_word_sentiment("cantar") }{ get_word_sentiment("cantar") }
OpLexicon is a sentiment lexicon for the Portuguese language. Please see SOUZA and VIEIRA (2012) and SOUZA et al. (2012) for its complete reference and documentation.
oplexicon_v2.1oplexicon_v2.1
A data frame with 30677 rows and 3 variables:
termcharacter. The word or term.
typecharacter. Grammar classification of the word or term.
polarityinteger. Numeric classification of the polarity or sentiment. It can only assume the values of -1, 0, and 1
http://ontolp.inf.pucrs.br/Recursos/downloads-OpLexicon.php
OpLexicon is a sentiment lexicon for the Portuguese language. Please see SOUZA and VIEIRA (2012) and SOUZA et al. (2012) for its complete reference and documentation.
oplexicon_v3.0oplexicon_v3.0
A data frame with 32191 rows and 4 variables:
termcharacter. The word of term. It also includes emoticons.
typecharacter. The type of the term.
polarityinteger. Numeric classification of the polarity or sentiment.
polarity_revisioncharacter. Was the polarity obtained manually (A) or automatically (C)?
http://ontolp.inf.pucrs.br/Recursos/downloads-OpLexicon.php
A sentiment lexicon designed for the extraction of sentiment and opinion about human entities in Portuguese texts. Please see SILVA, CARVALHO, COSTA and SARMENTO (2010) for its complete reference and documentation.
sentiLex_lem_PT02sentiLex_lem_PT02
A data frame with 7014 rows and 5 variables:
termcharacter The word of term.
grammar_categorycharacter. The grammar classification of the term.
polaritydouble. Numeric classification of the polarity or sentiment.
polarity_targetcharacter. Polarity target. It can be N0 (subject), N1 (complement) or N2 (no documentation was found for what it means).
polarity_classificationcharacter. Was the polarity obtained manually (MAN) or automatically (JALC)?.
Mário J. Silva, Paula Carvalho, Carlos Costa, Luís Sarmento, Automatic Expansion of a Social Judgment Lexicon for Sentiment Analysis Technical Report. TR 10-08. University of Lisbon, Faculty of Sciences, LASIGE, December 2010. doi: 10455/6694